#[repr(transparent)]pub struct SectionCharacteristics(pub u32);Tuple Fields
0: u32Implementations
Sourceimpl SectionCharacteristics
impl SectionCharacteristics
pub const IMAGE_SCN_TYPE_NO_PAD: Self
pub const IMAGE_SCN_CNT_CODE: Self
pub const IMAGE_SCN_CNT_INITIALIZED_DATA: Self
pub const IMAGE_SCN_CNT_UNINITIALIZED_DATA: Self
pub const IMAGE_SCN_LNK_OTHER: Self
pub const IMAGE_SCN_LNK_INFO: Self
pub const IMAGE_SCN_LNK_REMOVE: Self
pub const IMAGE_SCN_LNK_COMDAT: Self
pub const IMAGE_SCN_NO_DEFER_SPEC_EXC: Self
pub const IMAGE_SCN_GPREL: Self
pub const IMAGE_SCN_MEM_FARDATA: Self
pub const IMAGE_SCN_MEM_PURGEABLE: Self
pub const IMAGE_SCN_MEM_16BIT: Self
pub const IMAGE_SCN_MEM_LOCKED: Self
pub const IMAGE_SCN_MEM_PRELOAD: Self
pub const IMAGE_SCN_ALIGN_1BYTES: Self
pub const IMAGE_SCN_ALIGN_2BYTES: Self
pub const IMAGE_SCN_ALIGN_4BYTES: Self
pub const IMAGE_SCN_ALIGN_8BYTES: Self
pub const IMAGE_SCN_ALIGN_16BYTES: Self
pub const IMAGE_SCN_ALIGN_32BYTES: Self
pub const IMAGE_SCN_ALIGN_64BYTES: Self
pub const IMAGE_SCN_ALIGN_128BYTES: Self
pub const IMAGE_SCN_ALIGN_256BYTES: Self
pub const IMAGE_SCN_ALIGN_512BYTES: Self
pub const IMAGE_SCN_ALIGN_1024BYTES: Self
pub const IMAGE_SCN_ALIGN_2048BYTES: Self
pub const IMAGE_SCN_ALIGN_4096BYTES: Self
pub const IMAGE_SCN_ALIGN_8192BYTES: Self
pub const IMAGE_SCN_ALIGN_MASK: Self
pub const IMAGE_SCN_LNK_NRELOC_OVFL: Self
pub const IMAGE_SCN_MEM_DISCARDABLE: Self
pub const IMAGE_SCN_MEM_NOT_CACHED: Self
pub const IMAGE_SCN_MEM_NOT_PAGED: Self
pub const IMAGE_SCN_MEM_SHARED: Self
pub const IMAGE_SCN_MEM_EXECUTE: Self
pub const IMAGE_SCN_MEM_READ: Self
pub const IMAGE_SCN_MEM_WRITE: Self
Sourceimpl SectionCharacteristics
impl SectionCharacteristics
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SectionCharacteristics
impl SectionCharacteristics
Sourcepub const fn iter(&self) -> Iter<SectionCharacteristics>
pub const fn iter(&self) -> Iter<SectionCharacteristics>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SectionCharacteristics>
pub const fn iter_names(&self) -> IterNames<SectionCharacteristics>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.